==> core-v0.21.0-sources.jar: org/ice1000/jimgui/flag/JImItemFlags.java <==
package org.ice1000.jimgui.flag;

import org.ice1000.jimgui.*;
import org.ice1000.jimgui.flag.*;
import org.ice1000.jimgui.cpp.*;
import org.intellij.lang.annotations.*;
import org.jetbrains.annotations.*;
import java.nio.charset.StandardCharsets;

import static org.ice1000.jimgui.util.JImGuiUtil.*;

/**
 * @author ice1000
 * @since undecidable
 */
@SuppressWarnings("ALL")

public interface JImItemFlags {
  int None = 0;
  /**false+++++%7C%7C+Disable+keyboard+tabbing+%28FIXME%3A+should+merge+with+_NoNav%29*/
  int NoTabStop = 1 << 0;
  /**false+++++%7C%7C+Button%28%29+will+return+true+multiple+times+based+on+io.KeyRepeatDelay+and+io.KeyRepeatRate+settings.*/
  int ButtonRepeat = 1 << 1;
  /**false+++++%7C%7C+Disable+interactions+but+doesn%27t+affect+visuals.+See+PushDisabled%28%29%7CPushDisabled%28%29.+See+github.com%7Cocornut%7Cimgui%7Cissues%7C211*/
  int Disabled = 1 << 2;
  /**false+++++%7C%7C+Disable+keyboard%7Cgamepad+directional+navigation+%28FIXME%3A+should+merge+with+_NoTabStop%29*/
  int NoNav = 1 << 3;
  /**false+++++%7C%7C+Disable+item+being+a+candidate+for+default+focus+%28e.g.+used+by+title+bar+items%29*/
  int NoNavDefaultFocus = 1 << 4;
  /**false+++++%7C%7C+Disable+MenuItem%7CSelectable%28%29+automatically+closing+their+popup+window*/
  int SelectableDontClosePopup = 1 << 5;
  /**false+++++%7C%7C+%5BBETA%5D+Represent+a+mixed%7Cindeterminate+value%2C+generally+multi-selection+where+values+differ.+Currently+only+supported+by+Checkbox%28%29+%28later+should+support+all+sorts+of+widgets%29*/
  int MixedValue = 1 << 6;
  /**false+++++%7C%7C+%5BALPHA%5D+Allow+hovering+interactions+but+underlying+value+is+not+changed.*/
  int ReadOnly = 1 << 7;
  int Default = 0;
  enum Type implements Flag {
    None(JImItemFlags.None),
    NoTabStop(JImItemFlags.NoTabStop),
    ButtonRepeat(JImItemFlags.ButtonRepeat),
    Disabled(JImItemFlags.Disabled),
    NoNav(JImItemFlags.NoNav),
    NoNavDefaultFocus(JImItemFlags.NoNavDefaultFocus),
    SelectableDontClosePopup(JImItemFlags.SelectableDontClosePopup),
    MixedValue(JImItemFlags.MixedValue),
    ReadOnly(JImItemFlags.ReadOnly),
    Default(JImItemFlags.Default),
    ;
    public final int flag;
    Type(int flag) { this.flag = flag; }
    @Override public int get() { return flag; }
  }
}

==> core-v0.22.0-sources.jar: org/ice1000/jimgui/flag/JImItemFlags.java <==
package org.ice1000.jimgui.flag;

import org.ice1000.jimgui.*;
import org.ice1000.jimgui.flag.*;
import org.ice1000.jimgui.cpp.*;
import org.intellij.lang.annotations.*;
import org.jetbrains.annotations.*;
import java.nio.charset.StandardCharsets;

import static org.ice1000.jimgui.util.JImGuiUtil.*;

/**
 * @author ice1000
 * @since undecidable
 */
@SuppressWarnings("ALL")

public interface JImItemFlags {
  int None = 0;
  /**false+++++%7C%7C+Disable+keyboard+tabbing+%28FIXME%3A+should+merge+with+_NoNav%29*/
  int NoTabStop = 1 << 0;
  /**false+++++%7C%7C+Button%28%29+will+return+true+multiple+times+based+on+io.KeyRepeatDelay+and+io.KeyRepeatRate+settings.*/
  int ButtonRepeat = 1 << 1;
  /**false+++++%7C%7C+Disable+interactions+but+doesn%27t+affect+visuals.+See+BeginDisabled%28%29%7CEndDisabled%28%29.+See+github.com%7Cocornut%7Cimgui%7Cissues%7C211*/
  int Disabled = 1 << 2;
  /**false+++++%7C%7C+Disable+keyboard%7Cgamepad+directional+navigation+%28FIXME%3A+should+merge+with+_NoTabStop%29*/
  int NoNav = 1 << 3;
  /**false+++++%7C%7C+Disable+item+being+a+candidate+for+default+focus+%28e.g.+used+by+title+bar+items%29*/
  int NoNavDefaultFocus = 1 << 4;
  /**false+++++%7C%7C+Disable+MenuItem%7CSelectable%28%29+automatically+closing+their+popup+window*/
  int SelectableDontClosePopup = 1 << 5;
  /**false+++++%7C%7C+%5BBETA%5D+Represent+a+mixed%7Cindeterminate+value%2C+generally+multi-selection+where+values+differ.+Currently+only+supported+by+Checkbox%28%29+%28later+should+support+all+sorts+of+widgets%29*/
  int MixedValue = 1 << 6;
  /**false+++++%7C%7C+%5BALPHA%5D+Allow+hovering+interactions+but+underlying+value+is+not+changed.*/
  int ReadOnly = 1 << 7;
  int Default = 0;
  enum Type implements Flag {
    None(JImItemFlags.None),
    NoTabStop(JImItemFlags.NoTabStop),
    ButtonRepeat(JImItemFlags.ButtonRepeat),
    Disabled(JImItemFlags.Disabled),
    NoNav(JImItemFlags.NoNav),
    NoNavDefaultFocus(JImItemFlags.NoNavDefaultFocus),
    SelectableDontClosePopup(JImItemFlags.SelectableDontClosePopup),
    MixedValue(JImItemFlags.MixedValue),
    ReadOnly(JImItemFlags.ReadOnly),
    Default(JImItemFlags.Default),
    ;
    public final int flag;
    Type(int flag) { this.flag = flag; }
    @Override public int get() { return flag; }
  }
}
